@@ -37,4 +37,7 @@ SQUARE = 'square'
 # treeview constants
 TREE = 'tree'
 HEADINGS = 'headings'
-TREEHEADINGS = 'tree headings'
\ No newline at end of file
+TREEHEADINGS = 'tree headings'
+
+# state constants
+READONLY = 'readonly'
\ No newline at end of file
