@@ -10,6 +10,17 @@ from ttkbootstrap.icons import Icon
 from ttkbootstrap import utility
 
 
+def get_default_root(what=None):
+    if not tkinter._support_default_root:
+        raise RuntimeError("No master specified and tkinter is "
+                           "configured to not support default root")
+    if not tkinter._default_root:
+        if what:
+            raise RuntimeError(f"Too early to {what}: no default root window")
+        root = tkinter.Tk()
+        assert tkinter._default_root is root
+    return tkinter._default_root
+
 class Window(tkinter.Tk):
     """A class that wraps the tkinter.Tk class in order to provide a
     more convenient api with additional bells and whistles. For more
@@ -31,7 +42,7 @@ class Window(tkinter.Tk):
         self,
         title="ttkbootstrap",
         themename="litera",
-        iconphoto=None,
+        iconphoto='',
         size=None,
         position=None,
         minsize=None,
@@ -53,9 +64,13 @@ class Window(tkinter.Tk):
                 The name of the ttkbootstrap theme to apply to the
                 application.
 
-            iconphoto (PhotoImage):
-                The titlebar icon. This image is applied to all future
-                toplevels as well.
+            iconphoto (str):
+                A path to the image used for the titlebar icon.
+                Internally this is passed to the `Tk.iconphoto` method
+                and the image will be the default icon for all windows.
+                A ttkbootstrap image is used by default. To disable
+                this default behavior, set the value to `None` and use
+                the `Tk.iconphoto` or `Tk.iconbitmap` methods directly.
 
             size (Tuple[int, int]):
                 The width and height of the application window.
@@ -115,17 +130,26 @@ class Window(tkinter.Tk):
             utility.enable_high_dpi_awareness()
 
         super().__init__()
-        winsys = self.tk.call('tk', 'windowingsystem')
+        self.winsys = self.tk.call('tk', 'windowingsystem')
 
         if scaling is not None:
             utility.enable_high_dpi_awareness(self, scaling)
 
-        try:
-            self._icon = iconphoto or tkinter.PhotoImage(data=Icon.icon)
-            self.iconphoto(True, self._icon)
-        except tkinter.TclError:
-            # icon photo has already been applied in previous window creation
-            pass
+        if iconphoto is not None:
+            if iconphoto == '':
+                # the default ttkbootstrap icon
+                self._icon = tkinter.PhotoImage(data=Icon.icon)
+                self.iconphoto(True, self._icon)
+            else:
+                try:
+                    # the user provided an image path
+                    self._icon = tkinter.PhotoImage(file=iconphoto)
+                    self.iconphoto(True, self._icon)
+                except tkinter.TclError:
+                    # The fallback icon if the user icon fails.
+                    print('iconphoto path is bad; using default image.')
+                    self._icon = tkinter.PhotoImage(data=Icon.icon)
+                    self.iconphoto(True, self._icon)
 
         self.title(title)
 
@@ -156,7 +180,7 @@ class Window(tkinter.Tk):
             self.overrideredirect(1)
         
         if alpha is not None:
-            if winsys == 'x11':
+            if self.winsys == 'x11':
                 self.wait_visibility(self)
             self.attributes("-alpha", alpha)
 
@@ -184,24 +208,20 @@ class Window(tkinter.Tk):
     position_center = place_window_center # alias
 
     def _apply_entry_type_class_binding(self):
-        self.bind_class(
-            className="TEntry", 
-            sequence="<Configure>", 
-            func=self._disabled_state_cursor,
-            add="+"
-        )
-        self.bind_class(
-            className="TSpinbox", 
-            sequence="<Configure>", 
-            func=self._disabled_state_cursor,
-            add="+"
-        )
-        self.bind_class(
-            className="TCombobox", 
-            sequence="<Configure>", 
-            func=self._disabled_state_cursor,
-            add="+"
-        )
+        for className in ["TEntry", "TSpinbox", "TCombobox"]:
+            self.bind_class(
+                className=className, 
+                sequence="<Configure>", 
+                func=self._disabled_state_cursor,
+                add="+"
+            )
+
+            for sequence in ["<Control-a>", "<Control-A>"]:
+                self.bind_class(
+                    className=className, 
+                    sequence=sequence,
+                    func=self._on_select_all
+            )
 
     def _disabled_state_cursor(self, event):
         """Change the cursor of entry type widgets to 'arrow' if in a disabled
@@ -223,6 +243,11 @@ class Window(tkinter.Tk):
         except:
             pass
         
+    def _on_select_all(self, event):
+        event.widget.select_range(0, END)
+        event.widget.icursor(END)
+        return 'break'
+
 
 class Toplevel(tkinter.Toplevel):
     """A class that wraps the tkinter.Toplevel class in order to
@@ -244,7 +269,7 @@ class Toplevel(tkinter.Toplevel):
     def __init__(
         self,
         title="ttkbootstrap",
-        iconphoto=None,
+        iconphoto='',
         size=None,
         position=None,
         minsize=None,
@@ -264,9 +289,10 @@ class Toplevel(tkinter.Toplevel):
             title (str):
                 The title that appears on the application titlebar.
 
-            iconphoto (PhotoImage):
-                The titlebar icon. This image is applied to all future
-                toplevels as well.
+            iconphoto (str):
+                A path to the image used for the titlebar icon.
+                Internally this is passed to the `Tk.iconphoto` method.
+                By default the application icon is used.
 
             size (Tuple[int, int]):
                 The width and height of the application window.
@@ -331,12 +357,26 @@ class Toplevel(tkinter.Toplevel):
             **kwargs (Dict):
                 Other optional keyword arguments.
         """
-        super().__init__(**kwargs)
-        winsys = self.tk.call('tk', 'windowingsystem')
+        if 'iconify' in kwargs:
+            iconify = kwargs.pop('iconify')
+        else:
+            iconify = None
 
-        if iconphoto:
-            self._icon = iconphoto or tkinter.PhotoImage(data=Icon.icon)
-            self.iconphoto(False, self._icon)
+        super().__init__(**kwargs)
+        self.winsys = self.tk.call('tk', 'windowingsystem')
+        
+        if iconify:
+            self.iconify()
+
+        if iconphoto != '':
+            try:
+                # the user provided an image path
+                self._icon = tkinter.PhotoImage(file=iconphoto)
+                self.iconphoto(True, self._icon)
+            except tkinter.TclError:
+                # The fallback icon if the user icon fails.
+                print('iconphoto path is bad; using default image.')
+                pass
 
         self.title(title)
 
@@ -367,18 +407,18 @@ class Toplevel(tkinter.Toplevel):
             self.overrideredirect(1)
         
         if windowtype is not None:
-            if winsys == 'x11':
+            if self.winsys == 'x11':
                 self.attributes("-type", windowtype)
         
         if topmost:
             self.attributes("-topmost", 1)
         
         if toolwindow:
-            if winsys == 'win32':
+            if self.winsys == 'win32':
                 self.attributes("-toolwindow", 1)
         
         if alpha is not None:
-            if winsys == 'x11':
+            if self.winsys == 'x11':
                 self.wait_visibility(self)
             self.attributes("-alpha", alpha)
 
